(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	 Array.prototype.search = function(elem) {
		for(var i = 0; i < this.length; i++) {
			if(this[i] == elem) return i;
		}
		
		return -1;
	};
	
	var Multiselect = function(selector) {
		if(!$(selector)) {
			console.error("ERROR: Element %s does not exist.", selector);
			return;
		}
	
		this.selector = selector;
		this.selections = [];
	
		(function(that) {
			that.events();
		})(this);
	};
	
	Multiselect.prototype = {
		open: function(that) {
			var target = $(that).parent().attr("data-target");
	
			// If we are not keeping track of this one's entries, then
			// start doing so.
			if(!this.selections) {
				this.selections = [ ];
			}
	
			$(this.selector + ".multiselect").toggleClass("active");
		},
	
		close: function() {
			$(this.selector + ".multiselect").removeClass("active");
		},
	
		events: function() {
			var that = this;
	
			$(document).on("click", that.selector + ".multiselect > .title", function(e) {
				if(e.target.className.indexOf("close-icon") < 0) {
					that.open();
				}
			});
	
			$(document).on("click", that.selector + ".multiselect option", function(e) {
				var selection = $(this).attr("value");
				var target = $(this).parent().parent().attr("data-target");
	
				var io = that.selections.search(selection);
	
				if(io < 0) that.selections.push(selection);
				else that.selections.splice(io, 1);
	
				that.selectionStatus();
				that.setSelectionsString();
			});
	
			$(document).on("click", that.selector + ".multiselect > .title > .close-icon", function(e) {
				that.clearSelections();
			});
	
			$(document).click(function(e) {
				if(typeof e.target.className.indexOf === 'function') {
					if(e.target.className.indexOf("title") < 0) {
						if(e.target.className.indexOf("text") < 0) {
							if(e.target.className.indexOf("-icon") < 0) {
								if(e.target.className.indexOf("selected") < 0 ||
								e.target.localName != "option") {
									that.close();
								}
							}
						}
					}
				}
			});
		},
	
		selectionStatus: function() {
			var obj = $(this.selector + ".multiselect");
	
			if(this.selections.length) obj.addClass("selection");
			else obj.removeClass("selection");
		},
	
		clearSelections: function() {
			this.selections = [];
			this.selectionStatus();
			this.setSelectionsString();
		},
	
		getSelections: function() {
			return this.selections;
		},
	
		setSelectionsString: function() {
			var selects = this.getSelectionsString().split(", ");
			$(this.selector + ".multiselect > .title").attr("title", selects);
	
			var opts = $(this.selector + ".multiselect option");
	
			if(selects.length > 6) {
				var _selects = this.getSelectionsString().split(", ");
				_selects = _selects.splice(0, 6);
				$(this.selector + ".multiselect > .title > .text")
					.text(_selects + " [...]");
			}
			else {
				$(this.selector + ".multiselect > .title > .text")
					.text(selects);
			}
	
			for(var i = 0; i < opts.length; i++) {
				$(opts[i]).removeClass("selected");
			}
	
			for(var j = 0; j < selects.length; j++) {
				var select = selects[j];
	
				for(var i = 0; i < opts.length; i++) {
					if($(opts[i]).attr("value") == select) {
						$(opts[i]).addClass("selected");
						break;
					}
				}
			}
			$('#blocked_bot').val(selects);
		},
	
		getSelectionsString: function() {
			if(this.selections.length > 0)
				return this.selections.join(", ");
			else return "Select";
		},
	
		setSelections: function(arr) {
			if(!arr[0]) {
				error("ERROR: This does not look like an array.");
				return;
			}
	
			this.selections = arr;
			this.selectionStatus();
			this.setSelectionsString();
		},
	};
	var getUrlParameter = function getUrlParameter(sParam) {
		var sPageURL = window.location.search.substring(1),
			sURLVariables = sPageURL.split('&'),
			sParameterName,
			i;
	
		for (i = 0; i < sURLVariables.length; i++) {
			sParameterName = sURLVariables[i].split('=');
	
			if (sParameterName[0] === sParam) {
				return typeof sParameterName[1] === undefined ? true : decodeURIComponent(sParameterName[1]);
			}
		}
		return false;
	};
	$(document).ready(function() {
		var multi = new Multiselect("#dr-affilate-blocked_bot");
		jQuery.ajax({
			type: "post",
			dataType: "json",
			url: "admin-ajax.php",
			data: {action: "get_data"},
			success: function(msg){
				if(msg.success) {
				  localStorage.setItem('affiliate-links', JSON.stringify(msg.result));
				}
			}
		  });	
		  if(getUrlParameter('page')=== 'dr-affiliate-slug') {
			var ctx = document.getElementById('myChart').getContext('2d');
			var myChart = new Chart(ctx, {
				type: 'bar',
				data: {
					labels: ['Red', 'Blue', 'Yellow', 'Green', 'Purple', 'Orange'],
					datasets: [{
						label: '# of Votes',
						data: [12, 19, 3, 5, 2, 3],
						backgroundColor: [
							'rgba(255, 99, 132, 0.2)',
							'rgba(54, 162, 235, 0.2)',
							'rgba(255, 206, 86, 0.2)',
							'rgba(75, 192, 192, 0.2)',
							'rgba(153, 102, 255, 0.2)',
							'rgba(255, 159, 64, 0.2)'
						],
						borderColor: [
							'rgba(255, 99, 132, 1)',
							'rgba(54, 162, 235, 1)',
							'rgba(255, 206, 86, 1)',
							'rgba(75, 192, 192, 1)',
							'rgba(153, 102, 255, 1)',
							'rgba(255, 159, 64, 1)'
						],
						borderWidth: 1
					}]
				},
				options: {
					scales: {
						y: {
							beginAtZero: true
						}
					}
				}
			});	
		  }
		  $('#dismiss_msg_affiliate').click(function(){
			$('#notice_draffiliate').remove();
		  });
		  $(document).on('click','#feedback_click',function(){
				
		  });
	});
	
})( jQuery );
function updateStatus(e)
{
	var redirect_url=e.getAttribute('data-href');
	jQuery.ajax({
		type: "post",
		dataType: "json",
		url: "admin-ajax.php",
		data: {action: "done_review", review: "1"},
		success: function(msg){
			if(msg.success) {
				window.open(redirect_url,'_blank');
			}
		}
	});
}

jQuery(document).ready(function(e){
    jQuery('#img-upload').click(function(){
        var upload = wp.media({
        title:'Choose Image', //Title for Media Box
        multiple:false //For limiting multiple image
        })
        .on('select', function(){
            var select = upload.state().get('selection');
            var attach = select.first().toJSON();
            console.log(attach.id); //the attachment id of image
            console.log(attach.url); //url of image
			var column = jQuery('#img-upload').parent();
			column.empty();
			column.html('<span>'+attach.url+'</span>&nbsp;&nbsp;<a href="#" id="remove_img">Remove Image</a>');
            jQuery('#image_url').val(attach.url);
        })
        .open();
   });
   jQuery('#remove_img').click(function(){
		var column = jQuery(this).parent();
		console.log('hi');
		column.empty();
		column.html('<a href="#" class="page-title-action" id="img-upload">Add Image</a>');
		jQuery('#image_url').val('');
	});
}); 
