
import { registerBlockType } from '@wordpress/blocks';
import { SelectControl,Button } from '@wordpress/components';
const axios = require('axios');

registerBlockType( 'dr-affiliate/image', {
  title: 'Dr Affiliate Images',
  icon: 'format-image',
  category: 'layout',

  // Attributes for Latest Posts
  attributes: {
    selectedImage: { type: 'string' },
    links: { type: 'object' },
    flagImage: { type: 'boolean'},
    affiliateLink: {type: 'object'},
  },

  edit: function( props ) {
    let atts = props.attributes;
    
    // Get list of links if doesn't exists yet
    if( !atts.links ) {
		var data = new FormData();
		data.append('action', 'get_data_image');
		axios.post("admin-ajax.php", data)
      .then(function (response) {
        //console.log(response.data);
        props.setAttributes( { links: response.data.result });
      })
      .catch(function (error) {
        console.log(error.response);
      });
    }

    // If links not yet loaded
    if( !atts.links ) {
      return 'Loading...';
    }

    // If no links found
    if( atts.links && atts.links.length <= 0 ) {
      return 'No links found, please add some';
    }

	  const handleClick = (event) => {
      var data = new FormData();
      data.append('action', 'get_data_specific_image');
      data.append('affiliate_id',atts.selectedImage)
      axios.post("admin-ajax.php", data)
      .then(function (response) {
        // console.log(response.data);
        props.setAttributes({ flagImage: true, affiliateLink: response.data.result[0]});
      })
      .catch(function (error) {
        console.log(error.response);
      });
	  } 
    return (
    <>
    { !atts.flagImage && <div className={ props.className }>
      {/* Category select */}
      <SelectControl label="Affiliate Link"
        options={ [
          { label: 'Select a Affiliate Link', value: '' },
          // loop through links and create the options format
          // the triple dots is to merge this with the array
          ...atts.links.map( category => {
            return { label: category.title, value: category.id };
          } )
        ] }
        value={ atts.selectedImage }
        onChange={ value => props.setAttributes( { selectedImage: value } ) }
      />
	    <Button variant="secondary" onClick={ handleClick} className="button-primary ">Select</Button>
    </div>}
    { atts.affiliateLink && <figure>
        <img src={ atts.affiliateLink.image_path } />
    </figure> }
    </>
    )
  },

  // Let the gutenberg know that this will be rendered via render_callback in PHP
  // Or you can simply remove this function
  save: function( props ) {
    let atts = props.attributes;
    return (
      <div>
        { atts.affiliateLink && 
        <figure>
        <a className="dr_affiliate-links" href={atts.affiliateLink.cloaked_url}>
          <img src={ atts.affiliateLink.image_path } />
        </a>
      </figure> }
      </div>
    );
  }

} );